@@ -1,5 +1,5 @@
 from enum import Enum, auto
-from typing import List, Any
+from typing import List
 
 
 class AutoNameEnum(str, Enum):
@@ -37,5 +37,4 @@ class DefaultValues:
 
 class RouteTypes(AutoNameEnum):
     AMQP_RABBITMQ = auto()
-    SSE = auto()
     HTTP = auto()
